# Application Encryption

One of Sencha Desktop Packager's (SDP) primary features is its ability to keep your application code protected. A luxury not often afforded to applications written using web technologies, you need not sacrifice the integrity of your proprietary software when using SDP. To facilitate code protection, SDP uses modern encryption techniques to keep your code in an encrypted form on disk and over the wire.

### Basic Encryption

Out-of-the-box, SDP provides a seamless mode called [**Basic Encryption**](#!/guide/quick_ref-section-50) which will encrypt your application package automatically. Basic Encryption is turned on by default but can be disabled if desired.  This mode of encryption is recommended for securing your application with no additional work needed on your part. Please see the [manifest config option](#!/guide/quick_ref-section-50) for more information on controlling Basic Encryption.

### Advanced Encryption with Custom Keys

In addition to Basic Encryption, SDP allows you to provide your own public/private key pair for encryption. This provides a level of extra security to your application by allowing you to specify a custom set of encryption keys that are unique to you, rather than using the same keys shared by all  SDP packaged applications using Basic Encryption, and is therefore highly recommended.

SDP currently standardizes on the RSA public-key cipher, and therefore requires your key pair to be generated for the RSA algorithm. The cipher strength of your keys we leave up to your discretion. Because of the encryption algorithms SDP employs, using a larger key does not cause any diminished load times; we recommend using at least a 2048-bit key pair.

#### Key File Generation

There are a number of software tools available to generate RSA keys. We recommend [**OpenSSL**](http://www.openssl.org), which is widely available on all SDP supported platforms [including windows](http://www.openssl.org/related/binaries.html). Our instructions below utilize OpenSSL and can serve as an example of what is expected of other encryption software.

> ***Note**: Please be aware of your country's import/export laws regarding cryptography that apply to you. Sencha and OpenSSL are not responsible nor liable for any violations you make; it is **your** responsibility!*

To generate a fresh 2048-bit RSA private key:

<pre>
openssl genrsa -out privatekey.pem 2048
</pre>

> ***Note**: SDP currently does not support password protected private keys, therefore the above command will generate an unprotected private key. **Guard it well.***

The generated private key will be in PEM format, which is a standard ASN.1 formatted key that is Base64 encoded. SDP currently requires your public and private keys to be in DER binary format (i.e. ASN.1 that is *not* Base64 encoded). To convert your PEM key to DER format:

<pre>
openssl rsa -in privatekey.pem -out privatekey.der -outform der
</pre>

At this point your private key is ready for use with SDP. The last requirement will be to generate your public key file:

<pre>
openssl rsa -in privatekey.der -inform der -out publickey.der -outform der -pubout
</pre>

On Windows you can use PuTTY to generate your private key file, but will still need `openssl` to convert the file to DER and to generate the public key file. See *[PuTTY Key Generation](#!/guide/application_encryption-section-50)* below for details.

Now that you have your *privatekey.der* and *publickey.der* files, you're ready to configure SDP to use them.

#### Manifest Configuration

To use your key pair, SDP must be provided paths to your keys with two additional manifest config options:

1. [security.encryption.privateKeyPath](#!/guide/quick_ref-section-51)
2. [security.encryption.publicKeyPath](#!/guide/quick_ref-section-52)

An example configuration file might look like this:

	{
	    "organizationName": "Sencha",
	    "applicationName": "Area Chart",
	    "versionString": "1.0",
	    "outputPath": "AreaChart",
	    "webAppPath": "src/",
	    "settings": {
	    	"security": {
	    		"allowCrossSite": true,
	    		"encryption": {
	    			"privateKeyPath": "/path/to/privatekey.der",
	    			"publicKeyPath": "/path/to/publickey.der"
	    		}
	    	}
	    }
	}

When you run `ionpackage` to package your application, your encryption keys will be used instead of the Basic Encryption algorithm.

#### <span id="application_encryption-section-50">PuTTY Key Generation</span>

Putty users on windows can generate the private key in pem format using the PuTTY Key Generator (`puttygen.exe`).

Under the *Conversions* menu, select *Export OpenSSH key* and save the file.

{@img puttygen-3.png}

Once you have created your key, you will still need to use openssl to convert the key from PEM to DER format and to generate the public key:

<pre>
openssl rsa -in privatekey.pem -out privatekey.der -outform der
openssl rsa -in privatekey.der -inform der -out publickey.der -outform der -pubout
</pre>

