# Quick Reference

## ionpackage

<pre>
Usage: ionpackage [options] configFile.json

Options:
   --overwrite       Force overwriting the target path (if it already exists).
   -h or --help      Display this usage.
   --username=USER   Specify Sencha Forum user name (for generating license files)
   --password=PASSWD Specify Sencha Forum password (for generating license files)
   --activate[=KEY]  Use KEY to activate a full license.
</pre>

## Manifest File

The manifest file is JSON file which can be used to define various parameters used in packaging the application.

<div class='entry'>
<div class='entry-head'>organizationName [string]</div>
<div class='entry-body'>
The name of the organization responsible for the packaged application. This string will be used in Ion.io.userDataPath.
If <tt>organizationName</tt> is omitted, it will default to the value of <tt>applicationName</tt>.
</div>
</div>

<div class='entry'>
<div class='entry-head'>applicationName [string]</div>
<div class='entry-body'>
The name of the application. This will be the name of the executable file generated by <tt>ionpackage</tt>. It is also used in Ion.io.userDataPath.
</div>
</div>

<div class='entry'>
<div class='entry-head'>outputPath [string]</div>
<div class='entry-body'>
The name of the directory that stores the packaged application. If this is a relative path, it will be relative to where <tt>ionpackage</tt> is called from, i.e. the current working directory.
</div>
</div>

<div class='entry'>
<div class='entry-head'>dataDirectoryName [string]</div>
<div class='entry-body'>
The name of the directory that stores the application data, i.e. Ion.io.userDataPath. If <tt>dataDirectoryName</tt>
is not specified, it will default to the value of <tt>applicationName</tt>.
</div>
</div>

<div class='entry'>
<div class='entry-head'>applicationIconPaths [string[]]</div>
<div class='entry-body'>
An array of paths to the application's default icon files. These must be an <i>.ico</i> or an <i>.icns</i> icon file for Windows and Mac OS X respectively. If any of the provided paths are not absolute, they will be relative to your configuration file.
</div>
</div>
<div class='entry'>
<div class='entry-head'>versionString [string]</div>
<div class='entry-body'>
String describing the version of the packaged application.
</div>
</div>
<div class='entry'>
<div class='entry-head'>webAppPath [string]</div>
<div class='entry-body'>
Path of the directory containing the source files for the application being packaged. This path can be full or relative. If relative it is relative to the manifest file.
</div>
</div>
<div class='entry'>
<div class='entry-head'>settings</div>
<div class='entry-body'>
<p>This section contains application settings.</p>
<div class='entry'>
<div class='entry-head'>remoteDebuggingPort [number]</div>
<div class='entry-body'>
Port number to use for remote debugging. If this is not set, remote debugging is disabled. 
</div>
</div>
<div class='entry'>
<div class='entry-head'>mainWindow</div>
<p>This section contains parameters related to the main application window.</p>
<div class='entry-body'>
<div class='entry'>
<div class='entry-head'>autoShow [boolean: false]</div>
<div class='entry-body'>
If <tt>true</tt> the application window is made visible when the application launchs, otherwise the application remains invisible until a call is made to <a href='#!/api/Ion.ui.Window-method-show'>Ion.io.mainWindow.show</a>().
</div>
</div>
</div>
</div>
<div class='entry'>
<div class='entry-head'>security</div>
<div class='entry-body'>
<p>This section contains security related parameters.</p>
<div class='entry'>
<div class='entry-head'>allowCrossSite [boolean: false]</div>
<div class='entry-body'>
If <tt>true</tt> cross domain operations will be permitted. For example, using XMLHttpRequest calls to fetch assets from websites will be allowed.
</div>
</div>
<div class='entry'>
<div class='entry-head'>allowFileSystemAccess [boolean: false]</div>
<div class='entry-body'>
If <tt>true</tt> all requests to local file system (file://) URLs will be permitted by the application.
</div>
</div>
<div class='entry'>
<div class='entry-head'>allowJavaScriptClipboardAccess [boolean: false]</div>
<div class='entry-body'>
If <tt>true</tt>, JavaScript will be permitted to execute the HTML editing commands <i>Cut</i>, <i>Copy</i>, and <i>Paste</i>. E.g. <code>document.execCommand('Paste');</code>
</div>
</div>
</div>
</div>

</div>
</div>

<div class='entry'>
<div class='entry-head'>basicEncryption [boolean: true] <b>DEPRECATED</b></div>
<div class='entry-body'>
Defining basicEncryption here is deprecated and will cease to be supported in the near future.
If you want to use basicEncryption, please see <tt>encryption.basicEncryption</tt> below.
</div>
</div>

<div class='entry'>
<div class='entry-head'>encryption</div>
<div class='entry-body'>
This section contains the values used to specify <i>no encryption</i>, <i>basic encryption</i> or <i>encryption with a RSA key pair</i>. See the <a href="#!/guide/application_encryption">Application Encryption</a> guide for more information.
<br/>
If both public and private keys are specified, the value of <tt>basicEncryption</tt> is ignored.
<br/>
Otherwise, basic encryption will be used if <tt>basicEncryption</tt> is set to <tt>true</tt>, which is the default.
<div class='entry' id="quick_ref-section-50">
<div class='entry-head'>basicEncryption [boolean: true]</div>
<div class='entry-body'>
Basic encryption will be used if this value is true, and either the public key or private key or both are missing.
</div>
</div>

<div class='entry' id="quick_ref-section-51">
<div class='entry-head'>privateKeyPath [string]</div>
<div class='entry-body'>
Path to the file containing the DER formatted RSA private key to use for encryption.
This path can be full or relative. If relative, it is relative to the manifest file.
</div>
</div>

<div class='entry' id="quick_ref-section-52">
<div class='entry-head'>publicKeyPath [string]</div>
<div class='entry-body'>
Path to the file containing the DER formatted RSA public key to use for encryption.
This path can be full or relative. If relative, it is relative to the manifest file.
</div>
</div>

</div>
</div>
