# Create Your First Application

Once you've installed and used Sencha Desktop Packager for the first time by following the steps in the Getting Started guide, you're ready to use Sencha Desktop Packager to add native functionality to a packaged application. This guide shows how to do that. It shows you how to customize the `Hello, World!` application described in Getting Started by adding your own menu and file access APIs to make it look like a desktop application. 

## Add a menu

Sencha Desktop Packager provides menu APIs that let you to add menu bars and menu items to an application. The menu bar provides access to functions such as opening and closing files, displaying help or documentation, and providing interaction with various parts of the application.

Here is code you'd use to create a menu bar and add menu items. Insert this  inside a script tag in your `index.html` file or save it in a separate `.js` file.

    function addMenu() {
        var fileMenu = Ion.ui.mainWindow.menuBar.addMenu('File');
        fileMenu.addMenuItem('Change Color', changeColor);
        fileMenu.addSeparator();
        fileMenu.addMenuItem('Exit', handleExit);
    }

This adds a menu bar and also adds Change Color and Exit menu items, which are used to change the color of text and exit the app, respectively. Here's what they look like:

{@img tutorial1.png}

For more detail about the menu APIs, refer to the `Ion.ui.Menu` section of the [Sencha Desktop Packager API documentation](#!/api/Ion.ui.Menu).

### Add submenus

We can also add submenus using the Ion API. Here is code that does that:

    function addMenu() {
        var fileMenu = Ion.ui.mainWindow.menuBar.addMenu('File');
        var colorMenu = fileMenu.addMenu('Change Color');
        colorMenu.addMenuItem('Red', changeColorRed);
        colorMenu.addMenuItem('Green', changeColorGreen);
        colorMenu.addMenuItem('Blue', changeColorBlue);
    }

And here's what the submenu looks like:

{@img tutorial2.png}

You can also use IonMenu APIs to enable and disable menu items when the application calls for that. Here's what that looks like:

{@img tutorial3.png}



## File Access

Let's modify the Hello, World! example application so it can edit and save files. Here's the code for that:


    function handleSave() {
        var data = document.getElementById('txt1').value;
        var result = Ion.io.writeFile(filename, data);
    }

And here's what that looks like:

{@img tutorial4.png}

The app shows the text for the `.js` file, which can now be edited by selecting the Edit menu item inside the File menu. The File menu also contains a Save menu item as well as a Save As item which can be used to save the file with a different name and to a different location. 

For more information about the API for browsing files and directories, see the [Ion.io API documentation](#!/api/Ion.io).

After you save the file run the **ionpackage** command again to see your changes.
