/*jslint browser:true, sloppy:true*/
/*globals Ext:true, Ion:true*/

Ext.onReady(function () {
    var chartPanel,
        fileName = '',
        saveAsItem,
        win = Ion.ui.mainWindow;

    chartPanel = Ext.createWidget('viewport', {
        id: 'chartPanel',
        layout: 'fit'
    });

    function createChart(theme) {
        var chart, panel;
        chart = {
            id: 'chartCmp',
            xtype: 'chart',
            style: 'background:#fff',
            animate: false,
            theme: theme,
            store: window.store1,
            legend: {
                position: 'bottom'
            },
            axes: [{
                type: 'Numeric',
                position: 'left',
                fields: ['data1', 'data2', 'data3', 'data4', 'data5', 'data6', 'data7'],
                title: 'Number of Hits',
                grid: {
                    odd: {
                        opacity: 1,
                        fill: '#ddd',
                        stroke: '#bbb',
                        'stroke-width': 1
                    }
                },
                minimum: 0,
                adjustMinimumByMajorUnit: 0
            }, {
                type: 'Category',
                position: 'bottom',
                fields: ['name'],
                title: 'Month of the Year',
                label: {
                    rotate: {
                        degrees: 315
                    }
                }
            }],
            series: [{
                type: 'area',
                highlight: false,
                axis: 'left',
                xField: 'name',
                yField: ['data1', 'data2', 'data3', 'data4', 'data5', 'data6', 'data7'],
                style: {
                    opacity: 0.93
                }
            }]
        };
        panel = Ext.getCmp('chartPanel');
        panel.add(chart);
    }

    function saveData(path) {
        var data = JSON.stringify(Ext.Array.map(window.store1.getRange(), function (o) { return o.data; }), null, '    ');

        if (Ion.io.writeFile(path, data)) {
            saveAsItem.setEnabled(true);
            fileName = path;
        }
    }

    function handleSaveAs() {
        var result,
            overwrite = true;

        result = Ion.io.browseFiles({
            caption: 'Save Chart Data',
            defaultValue: 'chartdata.json',
            path: fileName,
            filters: [['JSON Files', '*.json']]
        });
        if (result.success) {
            if (Ion.io.pathExists(result.value)) {
                overwrite = window.confirm("File exists\nOk to overwrite it?");
            }
            if (overwrite) {
                saveData(result.value);
            }
        }
    }

    function handleSave() {
        if (fileName) {
            saveData(fileName);
        } else {
            handleSaveAs();
        }
    }

    function handleOpen() {
        var result, path;

        result = Ion.io.browseFiles({
            caption: 'Load Chart Data',
            path: fileName,
            filters: [['JSON Files', '*.json']],
            type: 'open'
        });
        if (result.success) {
            path = result.value;
            result = Ion.io.readFile(path);
            if (result.success) {
                window.store1.loadData(JSON.parse(result.data));
                saveAsItem.setEnabled(true);
                fileName = path;
            }
        }
    }

    function handleRegenerate() {
        var chart = Ext.getCmp('chartCmp');
        chart.animate = true;
        window.store1.loadData(window.generateData());
        chart.animate = false;
    }

    function setTheme(colorScheme) {
        return function () {
            var chart = Ext.getCmp('chartCmp'),
                panel = Ext.getCmp('chartPanel');

            panel.remove('chartCmp');
            chart.destroy();

            createChart(colorScheme);
        };
    }

    function handleExit() {
        return window.confirm('Do you really want to exit?');
    }

    function addMenu() {
        var fileMenu, dataMenu, themeMenu, themeCategoryMenu;

        fileMenu = win.menuBar.addMenu('File');
        fileMenu.addMenuItem('Open', handleOpen, 'Ctrl+O');
        fileMenu.addMenuItem('Save', handleSave, 'Ctrl+S');

        fileMenu.addSeparator();
        saveAsItem = fileMenu.addMenuItem('Save As', handleSaveAs, 'Ctrl+Shift+S');
        saveAsItem.setEnabled(false);

        if (Ion.sys.os != 'mac') {
            fileMenu.addSeparator();

            var exitKeys = Ion.sys.os == 'windows' ? 'Alt+F4' : 'Ctrl+Q';
            fileMenu.addMenuItem('Exit', Ext.bind(win.close, win, []), exitKeys);
        }

        dataMenu = Ion.ui.mainWindow.menuBar.addMenu('Data');
        dataMenu.addMenuItem('Regenerate Data', handleRegenerate, 'Ctrl+R');
        dataMenu.addSeparator();

        themeMenu = dataMenu.addMenu("Set Theme");
        themeMenu.addMenuItem('Base', setTheme('Base'));
        themeMenu.addMenuItem('Green', setTheme('Green'));
        themeMenu.addMenuItem('Sky', setTheme('Sky'));
        themeMenu.addMenuItem('Red', setTheme('Red'));
        themeMenu.addMenuItem('Purple', setTheme('Purple'));
        themeMenu.addMenuItem('Blue', setTheme('Blue'));
        themeMenu.addMenuItem('Yellow', setTheme('Yellow'));

        themeCategoryMenu = themeMenu.addMenu("Category");
        themeCategoryMenu.addMenuItem('Category1', setTheme('Category1'));
        themeCategoryMenu.addMenuItem('Category2', setTheme('Category2'));
        themeCategoryMenu.addMenuItem('Category3', setTheme('Category3'));
        themeCategoryMenu.addMenuItem('Category4', setTheme('Category4'));
        themeCategoryMenu.addMenuItem('Category5', setTheme('Category5'));
        themeCategoryMenu.addMenuItem('Category6', setTheme('Category6'));
    }

    addMenu();
    createChart('Base');

    win.setDimensions(800, 635);
    win.center();
    win.show();

    win.closing.connect(handleExit);
});
