/*jslint browser:true, plusplus: true, sloppy:true*/
/*globals Ext:true, Ion:true, alert:true */

var current_directory, sep = '/';

// return true if current_directory is the root
function isRoot() {
    var p;
    if (current_directory.length > 0) {
        if (current_directory === sep) {
            return true;
        }

        p = current_directory.indexOf(sep);
        if (p < 0 || p >= current_directory.length - 1) {
            return true;
        }
    }
    return false;
}

function loadDirectory() {
    var cwd, contents, d_list, f_list, up_button, tbl, col, entry,
        i, isText, ext, icon, clss;

    cwd = document.getElementById('cwd');
    contents = document.getElementById('contents');

    cwd.innerHTML = current_directory;

    try {
        d_list = Ion.io.listDirectory(current_directory, { directories: true, files: false });
    } catch (err1) {
        alert('EXCEPTION:\n\n' + err1);
    }

    try {
        f_list = Ion.io.listDirectory(current_directory, { directories: false, files: true });
    } catch (err2) {
        alert('EXCEPTION:\n\n' + err2);
    }

    if (d_list.length === 0 && f_list.length === 0) {
        contents.innerHTML = 'EMPTY';

        up_button = document.getElementById('up_button');
        up_button.disabled = isRoot();

    } else {

        // XXX Move style stuff to css file
        tbl = '<table class="dirtable" border="1" cellpadding="3" cellspacing="0">';
        col = 0;

        for (entry in d_list) {
            if (d_list.hasOwnProperty(entry)) {
                if (col === 0) {
                    tbl += '<tr>';
                }
                tbl += '<td class="directory-entry" onclick="go_down(\'' + d_list[entry] +
                    '\')"><img src="Folder.png"/>&nbsp;' + d_list[entry] + '</td>';
                col++;
                if (col > 2) {
                    tbl += '</tr>';
                    col = 0;
                }
            }
        }
        if (col < 3 && col !== 0) {
            while (col < 3) {
                tbl += '<td>&nbsp;</td>';
                col++;
            }
            tbl += '</tr>';
        }

        col = 0;
        for (entry in f_list) {
            if (f_list.hasOwnProperty(entry)) {
                if (col === 0) {
                    tbl += '<tr>';
                }
                // try to guess the file type from the extension.
                // only support '.txt' files for this example.
                i = f_list[entry].lastIndexOf('.');
                isText = false;

                ext = f_list[entry].substring(i).toLowerCase();
                if (i > 0 && ((ext === '.txt') || (ext === '.json') || (ext === '.bat') ||
                    (ext === '.py') || (ext === '.c') || (ext === '.cpp') || (ext === '.h') ||
                    (ext === '.xml') || (ext === '.js') || (ext === '.html') || (ext === '.log') || (ext === '.patch'))) {
                    isText = true;
                }

                icon = isText ? '<img src="text_doc.png"/>&nbsp;' :  '<img src="other_doc.png"/>&nbsp;';
                clss = isText ? 'textfile-entry' : 'file-entry';
                tbl += '<td class="' + clss + '"';
                if (isText) {
                    tbl += ' onclick="load_file(\'' + f_list[entry] + '\')"';
                }
                tbl += '>' + icon + f_list[entry] + '</td>';
                col++;

                if (col > 2) {
                    tbl += '</tr>';
                    col = 0;
                }
            }
        }
        if (col < 3 && col !== 0) {
            while (col < 3) {
                tbl += '<td>&nbsp;</td>';
                col++;
            }
            tbl += '</tr>';
        }
        tbl += '</table>';
        contents.innerHTML = tbl;

        up_button = document.getElementById('up_button');
        up_button.disabled = isRoot();
    }
}

function get_ready() {
    current_directory = Ion.io.userDocsPath;
    if (!current_directory) {
        current_directory = Ion.io.userHomePath;
    }
    // Chop off the trailing slash.
    current_directory = current_directory.substr(0, current_directory.length - 1);

    loadDirectory();
}

function go_up() {
    var i, fileItem, nameItem;

    i = current_directory.lastIndexOf(sep);
    if (i >= 0) {
        fileItem = document.getElementById('file-data');
        fileItem.innerHTML = '';
        nameItem = document.getElementById('filename');
        nameItem.innerHTML = '';
        current_directory = (i === 0) ? sep : current_directory.substr(0, i);
        if (current_directory.indexOf(sep) < 0) {
            current_directory += sep;
        }
        loadDirectory();
    }
}

function go_down(dirname) {
    var fileItem, nameItem;

    fileItem = document.getElementById('file-data');
    fileItem.innerHTML = '';
    nameItem = document.getElementById('filename');
    nameItem.innerHTML = '';
    if (current_directory === sep) {
        current_directory = '';
    }
    if (current_directory[current_directory.length - 1] !== sep) {
        current_directory += sep;
    }
    current_directory += dirname;
    loadDirectory();
}

function load_file(filename) {
    var path, data, fileItem, nameItem;

    path = current_directory + sep + filename;
    data = Ion.io.readFile(path);

    fileItem = document.getElementById('file-data');
    nameItem = document.getElementById('filename');
    if (data.success) {
        nameItem.innerHTML = '<b>Contents of<br/><i>' + path + '</i></b>';
        fileItem.innerHTML = data.data;
    } else {
        nameItem.innerHTML = '<b>FAILED TO READ FILE</b>';
        fileItem.innerHTML = '';
    }
}
