/*jslint browser:true, sloppy:true*/
/*globals Ext:true, Ion:true*/

Ext.onReady(function () {
    var win = Ion.ui.mainWindow,
        myData, ds, store, gridForm;

    Ext.QuickTips.init();

    // sample static data for the store
    myData = [
        ['3m Co',                               71.72, 0.02,  0.03,  '9/1 12:00am'],
        ['Alcoa Inc',                           29.01, 0.42,  1.47,  '9/1 12:00am'],
        ['Altria Group Inc',                    83.81, 0.28,  0.34,  '9/1 12:00am'],
        ['American Express Company',            52.55, 0.01,  0.02,  '9/1 12:00am'],
        ['American International Group, Inc.',  64.13, 0.31,  0.49,  '9/1 12:00am'],
        ['AT&T Inc.',                           31.61, -0.48, -1.54, '9/1 12:00am'],
        ['Boeing Co.',                          75.43, 0.53,  0.71,  '9/1 12:00am'],
        ['Caterpillar Inc.',                    67.27, 0.92,  1.39,  '9/1 12:00am'],
        ['Citigroup, Inc.',                     49.37, 0.02,  0.04,  '9/1 12:00am'],
        ['E.I. du Pont de Nemours and Company', 40.48, 0.51,  1.28,  '9/1 12:00am'],
        ['Exxon Mobil Corp',                    68.1,  -0.43, -0.64, '9/1 12:00am'],
        ['General Electric Company',            34.14, -0.08, -0.23, '9/1 12:00am'],
        ['General Motors Corporation',          30.27, 1.09,  3.74,  '9/1 12:00am'],
        ['Hewlett-Packard Co.',                 36.53, -0.03, -0.08, '9/1 12:00am'],
        ['Honeywell Intl Inc',                  38.77, 0.05,  0.13,  '9/1 12:00am'],
        ['Intel Corporation',                   19.88, 0.31,  1.58,  '9/1 12:00am'],
        ['International Business Machines',     81.41, 0.44,  0.54,  '9/1 12:00am'],
        ['Johnson & Johnson',                   64.72, 0.06,  0.09,  '9/1 12:00am'],
        ['JP Morgan & Chase & Co',              45.73, 0.07,  0.15,  '9/1 12:00am'],
        ['McDonald\'s Corporation',             36.76, 0.86,  2.40,  '9/1 12:00am'],
        ['Merck & Co., Inc.',                   40.96, 0.41,  1.01,  '9/1 12:00am'],
        ['Microsoft Corporation',               25.84, 0.14,  0.54,  '9/1 12:00am'],
        ['Pfizer Inc',                          27.96, 0.4,   1.45,  '9/1 12:00am'],
        ['The Coca-Cola Company',               45.07, 0.26,  0.58,  '9/1 12:00am'],
        ['The Home Depot, Inc.',                34.64, 0.35,  1.02,  '9/1 12:00am'],
        ['The Procter & Gamble Company',        61.91, 0.01,  0.02,  '9/1 12:00am'],
        ['United Technologies Corporation',     63.26, 0.55,  0.88,  '9/1 12:00am'],
        ['Verizon Communications',              35.57, 0.39,  1.11,  '9/1 12:00am'],
        ['Wal-Mart Stores, Inc.',               45.45, 0.73,  1.63,  '9/1 12:00am']
    ];

    ds = Ext.create('Ext.data.ArrayStore', {
        storeId: 'mystore',
        fields: [
            {name: 'company'},
            {name: 'price',      type: 'float'},
            {name: 'change',     type: 'float'},
            {name: 'pctChange',  type: 'float'},
            {name: 'lastChange', type: 'date', dateFormat: 'n/j h:ia'},
            // Rating dependent upon performance 0 = best, 2 = worst
            {name: 'rating', type: 'int', convert: function (value, record) {
                var pct = record.get('pctChange');
                if (pct < 0) {
                    return 2;
                }
                if (pct < 1) {
                    return 1;
                }
                return 0;
            }}
        ],
        data: myData
    });

    store = Ext.StoreMgr.lookup('mystore');

    // example of custom renderer function
    function change(val) {
        if (val > 0) {
            return '<span style="color:green;">' + val + '</span>';
        }
        if (val < 0) {
            return '<span style="color:red;">' + val + '</span>';
        }
        return val;
    }

    // example of custom renderer function
    function pctChange(val) {
        if (val > 0) {
            return '<span style="color:green;">' + val + '%</span>';
        }
        if (val < 0) {
            return '<span style="color:red;">' + val + '%</span>';
        }
        return val;
    }

    // render rating as "A", "B" or "C" depending upon numeric value.
    function rating(v) {
        if (v == 0) {
            return "A";
        }
        if (v == 1) {
            return "B";
        }
        if (v == 2) {
            return "C";
        }
    }


    /*
     * Here is where we create the Form
     */
    gridForm = Ext.create('Ext.form.Panel', {
        id: 'company-form',
        frame: true,
        bodyPadding: 5,
        layout: {
            type: 'hbox',
            align: 'stretch'
        },

        fieldDefaults: {
            labelAlign: 'left',
            msgTarget: 'side'
        },

        items: [{
            flex: 2,
            xtype: 'gridpanel',
            store: ds,
            title: 'Company Data',

            columns: [
                {
                    id       : 'company',
                    text   : 'Company',
                    flex: 1,
                    sortable : true,
                    dataIndex: 'company'
                },
                {
                    text   : 'Price',
                    width    : 75,
                    sortable : true,
                    dataIndex: 'price'
                },
                {
                    text   : 'Change',
                    width    : 75,
                    sortable : true,
                    renderer : change,
                    dataIndex: 'change'
                },
                {
                    text   : '% Change',
                    width    : 75,
                    sortable : true,
                    renderer : pctChange,
                    dataIndex: 'pctChange'
                },
                {
                    text   : 'Last Updated',
                    width    : 85,
                    sortable : true,
                    renderer : Ext.util.Format.dateRenderer('m/d/Y'),
                    dataIndex: 'lastChange'
                },
                {
                    text: 'Rating',
                    width: 30,
                    sortable: true,
                    renderer: rating,
                    dataIndex: 'rating'
                }
            ],

            listeners: {
                selectionchange: function (model, records) {
                    if (records[0]) {
                        this.up('form').getForm().loadRecord(records[0]);
                    }
                }
            }
        }, {
            flex: 1,
            margin: '0 0 0 10',
            xtype: 'fieldset',
            title: 'Company details',
            defaults: {
                width: 240,
                labelWidth: 90
            },
            defaultType: 'textfield',
            items: [{
                fieldLabel: 'Name',
                name: 'company'
            }, {
                fieldLabel: 'Price',
                name: 'price'
            }, {
                fieldLabel: '% Change',
                name: 'pctChange'
            }, {
                xtype: 'datefield',
                fieldLabel: 'Last Updated',
                name: 'lastChange'
            }, {
                xtype: 'radiogroup',
                fieldLabel: 'Rating',
                columns: 3,
                defaults: {
                    name: 'rating' //Each radio has the same name so the browser will make sure only one is checked at once
                },
                items: [{
                    inputValue: '0',
                    boxLabel: 'A'
                }, {
                    inputValue: '1',
                    boxLabel: 'B'
                }, {
                    inputValue: '2',
                    boxLabel: 'C'
                }]
            }]
        }]
    });

    Ext.createWidget('viewport', {
        layout: 'fit',
        items: [gridForm]
    });

    function handleExit() {
        return window.confirm('Do you really want to exit?');
    }

    function addMenu() {
        function sortByCompanyAsc() {
            store.sort('company', 'ASC');
        }

        function sortByCompanyDesc() {
            store.sort('company', 'DESC');
        }

        function sortByPriceAsc() {
            store.sort('price', 'ASC');
        }

        function sortByPriceDesc() {
            store.sort('price', 'DESC');
        }

        function sortByChangeAsc() {
            store.sort('change', 'ASC');
        }

        function sortByChangeDesc() {
            store.sort('change', 'DESC');
        }

        function sortBypctChangeAsc() {
            store.sort('pctChange', 'ASC');
        }

        function sortBypctChangeDesc() {
            store.sort('pctChange', 'DESC');
        }

        function sortBylastChangeAsc() {
            store.sort('lastChange', 'ASC');
        }

        function sortBylastChangeDesc() {
            store.sort('lastChange', 'DESC');
        }

        var fileMenu, sortMenu, orderComp, orderPrice, orderChange, orderpctChange, orderlastChange;

        if (Ion.sys.os != 'mac') {
            fileMenu = win.menuBar.addMenu('File');

            var exitKeys = Ion.sys.os == 'windows' ? 'Alt+F4' : 'Ctrl+Q';
            fileMenu.addMenuItem('Exit', Ext.bind(win.close, win, []), exitKeys);
        }

        sortMenu = win.menuBar.addMenu('Sort');

        orderComp = sortMenu.addMenu('Company');
        orderComp.addMenuItem('Ascending', sortByCompanyAsc);
        orderComp.addMenuItem('Descending', sortByCompanyDesc);

        orderPrice = sortMenu.addMenu('Price');
        orderPrice.addMenuItem('Ascending', sortByPriceAsc);
        orderPrice.addMenuItem('Descending', sortByPriceDesc);

        orderChange = sortMenu.addMenu('Change');
        orderChange.addMenuItem('Ascending', sortByChangeAsc);
        orderChange.addMenuItem('Descending', sortByChangeDesc);

        orderpctChange = sortMenu.addMenu('% Change');
        orderpctChange.addMenuItem('Ascending', sortBypctChangeAsc);
        orderpctChange.addMenuItem('Descending', sortBypctChangeDesc);

        orderlastChange = sortMenu.addMenu('Last Updated');
        orderlastChange.addMenuItem('Ascending', sortBylastChangeAsc);
        orderlastChange.addMenuItem('Descending', sortBylastChangeDesc);
    }

    gridForm.child('gridpanel').getSelectionModel().select(0);
    addMenu();

    win.setDimensions(1024, 768);
    win.center();
    win.show();

    win.closing.connect(handleExit);
});
