Ext.data.JsonP.getting_started({"title":"Getting Started","guide":"<h1>Getting Started With Sencha Desktop Packager</h1>\n<div class='toc'>\n<p><strong>Contents</strong></p>\n<ol>\n<li><a href='#!/guide/getting_started-section-1'>System Requirements</a></li>\n<li><a href='#!/guide/getting_started-section-2'>Installation</a></li>\n<li><a href='#!/guide/getting_started-section-3'>Registration</a></li>\n<li><a href='#!/guide/getting_started-section-4'>Packaging a Simple App</a></li>\n<li><a href='#!/guide/getting_started-section-5'>Next steps</a></li>\n</ol>\n</div>\n\n<p>The primary goal of Sencha Desktop Packager is to wrap an application written in HTML, CSS, and JavaScript with a native shell so it will launch, look, and behave like a normal desktop application. The converted application will run directly on the operating system without a web browser. This permits easy deployment and installation. <a href=\"#!/api\" title=\"API documentation\">Additional APIs</a> from the native shell run-time enables you to add an application menu, invoke file dialogs, and create many user interaction features that usually are not available if the application runs in a web browser.</p>\n\n<p>This guide describes the system requirements for Sencha Desktop Packager, how to install it, and how to use it to package an application.</p>\n\n<h2 id='getting_started-section-1'>System Requirements</h2>\n\n<p>Sencha Desktop Packager is available for these platforms:</p>\n\n<ul>\n<li>Microsoft Windows XP or newer (32-bit and 64-bit)</li>\n<li>Apple Mac OS X Snow Leopard or newer (32-bit and 64-bit)</li>\n<li>Ubuntu Linux 10.04 or newer, other equivalent Linux distributions (32-bit and 64-bit)</li>\n</ul>\n\n\n<h2 id='getting_started-section-2'>Installation</h2>\n\n<p>The process to install Sencha Desktop Packager is the same for all platforms:</p>\n\n<ol>\n<li>Download the Sencha Desktop Packager .zip file.</li>\n<li>Create a directory, giving it a name without spaces or special characters, and unzip Sencha Desktop Packager to the new directory.</li>\n<li>Add the directory to the PATH environment variable.</li>\n</ol>\n\n\n<p>The installation directory should now have the following files:</p>\n\n<ul>\n<li><code>examples/</code> directory for all the included example code</li>\n<li><code>docs/</code> directory for the documentation</li>\n<li><code>ionpackage</code>, the main packaging command-line tool (<code>ionpackage.exe</code> on Windows)</li>\n<li><code>ionruntime.dat</code>, the packaging library</li>\n</ul>\n\n\n<h2 id='getting_started-section-3'>Registration</h2>\n\n<p>You are required to register Sencha Desktop Packager and obtain a license before you can use it. The first time you run <tt>ionpackage</tt> you will be prompted to provide the information required.</p>\n\n<p>See the <a href=\"#!/guide/licensing\">Licensing Guide</a> for details.</p>\n\n<h3>Running For the First Time</h3>\n\n<p>After installation, run the command <code>ionpackage</code> in the Windows Command Prompt.</p>\n\n<p>Running the command should display the program information, as shown below. Here's the program information on a Windows system:</p>\n\n<p><p><img src=\"guides/getting_started/ionpackage_windows.png\" alt=\"\"></p></p>\n\n<p>And here's the program information on an OS X system:</p>\n\n<p><p><img src=\"guides/getting_started/ionpackage_osx.png\" alt=\"\"></p></p>\n\n<p>And here's how it looks on Linux:</p>\n\n<p><p><img src=\"guides/getting_started/ionpackage_linux.png\" alt=\"\"></p></p>\n\n<h2 id='getting_started-section-4'>Packaging a Simple App</h2>\n\n<p>Converting a web app into a desktop app involves a few simple steps. After installing Sencha Desktop Packager, create a manifest file using JSON that describes the application. Here's an example of a simple manifest file called <code>helloconfig.json</code>:</p>\n\n<pre><code>   {\n       \"applicationName\": \"Hello World\",\n       \"applicationIconPaths\": [\"HelloWorld.ico\", \"HelloWorld.icns\"],\n       \"versionString\": \"1.0\",\n       \"outputPath\": \"HelloWorld\",\n       \"webAppPath\": \"hello/\",\n       \"settings\": {\n           \"mainWindow\": {\n               \"autoShow\": true\n           }\n       }\n   }\n</code></pre>\n\n<p>The key-value pairs used in this example are:</p>\n\n<ul>\n<li><code>applicationName</code> denotes the name of the application, which will be visible to the user.</li>\n<li><code>applicationIconPaths</code> denotes an array of paths to the application's default icon files. These must be an <em>.ico</em> or an <em>.icns</em> icon file for Windows and Mac OS X respectively. If any of the provided paths are not absolute, they will be relative to your configuration file.</li>\n<li><code>versionString</code> sets the version number of the application.</li>\n<li><code>outputPath</code> points to a location where the application will be generated.</li>\n<li><code>webAppPath</code> points to the source directory of the application.</li>\n<li><code>settings.mainWindow.autoShow</code> Ensures that the application window is displayed on the screen.</li>\n</ul>\n\n\n<p><code>outputPath</code> and <code>webAppPath</code> can be relative or absolute. If relative they will be interpreted relative to the location of the manifest file.</p>\n\n<p><code>autoShow</code> is set to <code>true</code> in this simple example to make the window visible without writing any JavaScript to explicitly show it. This is not the default behavior. See <a href=\"#!/guide/configuration-section-50\">mainWindow</a> in the Advanced Configuration Guide for details on how and when to use <code>autoShow</code>.</p>\n\n<p>The <a href=\"#!/guide/quick_ref\">Quick Reference Guide</a> contains documentation all of the key-value pairs that can be specified in the manifest file.</p>\n\n<p>Next let's look at the content of a simple <code>Hello, world!</code> HTML application. The app is stored in a file called <code>index.html</code> under the <code>hello/</code> subdirectory specified in the above example. Here's what the code looks like:</p>\n\n<pre><code>    &lt;html&gt;\n    &lt;head&gt;\n        &lt;title&gt;Hello&lt;/title&gt;\n    &lt;/head&gt;\n    &lt;body&gt;\n        &lt;p&gt;Hello, world!&lt;/p&gt;\n    &lt;/body&gt;\n    &lt;/html&gt;\n</code></pre>\n\n<p>Now, using the manifest file and the HTML application, we can create the desktop application with Sencha Desktop Packager using the following command:</p>\n\n<pre>> ionpackage helloconfig.json\n</pre>\n\n\n<p><strong>Note:</strong> If this is the very first time you run <code>ionpackage</code>, you will be prompted to register the product. See the <a href=\"#!/guide/licensing\">Licensing Guide</a> for details.</p>\n\n<p>Packaging a simple app like our <em>Hello World</em> example will only take a few seconds. If the directory specified by <code>outputPath</code> (<code>./HelloWorld</code> in this example) does not exist, <code>ionpackage</code> will create it. If it does exist, <code>ionpackage</code> will prompt asking whether or not to overwrite it. Be careful though, because opting to overwrite will delete any previous contents of <code>outputPath</code>.</p>\n\n<pre>...\nOutput path already exists. Overwrite (Y/N)? y\nOutput path will be overwritten.\n...\n</pre>\n\n\n<p>When <code>ionpackage</code> finishes running, the newly packaged app will be in <code>outputPath</code>.</p>\n\n<p>If you open the <code>HelloApp</code> directory in Windows, you'll see the following:</p>\n\n<p><p><img src=\"guides/getting_started/getting_started3.png\" alt=\"\"></p></p>\n\n<p>Note that the main application created by Sencha Desktop Packager is <code>HelloWorld.exe</code>. Double-click this file to launch the application.</p>\n\n<p>Here's the <code>HelloApp</code> directory open in OS X:</p>\n\n<p><p><img src=\"guides/getting_started/getting_started4.png\" alt=\"\"></p></p>\n\n<p>Here's the application running in Windows:</p>\n\n<p><p><img src=\"guides/getting_started/getting_started5.png\" alt=\"\"></p></p>\n\n<p>And here's our <code>Hello, World!</code> app running in OS X:</p>\n\n<p><p><img src=\"guides/getting_started/getting_started6.png\" alt=\"\"></p></p>\n\n<h2 id='getting_started-section-5'>Next steps</h2>\n\n<p>Sencha Desktop Packager documentation includes the following, and we recommend you look at them in this order:</p>\n\n<ul>\n<li><a href=\"#!/guide/tutorial\">Tutorial guide</a>: Learn how to add custom native functionality to the <code>Hello, World!</code> application</li>\n<li><a href=\"#!/guide/examples\">Examples guide</a>: Learn about the examples that come with Sencha Desktop Packager</li>\n<li><a href=\"#!/guide/configuration\">Advanced configuration</a>: Learn about advanced settings for manifest files</li>\n<li><a href=\"#!/quick_ref\">Quick Reference guide</a>: a <em>Man page</em> for <code>ionpackage</code> and manifest files</li>\n<li><a href=\"#!/api\">API documentation</a>: Find detailed docs for all of the APIs provided with Sencha Desktop Packager</li>\n</ul>\n\n"});